==> ML360_NLP_Preprocessing-0.0.1.tar.gz: ML360_NLP_Preprocessing-0.0.1/setup.py <==
from distutils.core import setup
setup(
  name = 'ML360_NLP_Preprocessing',         # How you named your package folder (MyLib)
  packages = ['ML360_NLP_Preprocessing'],   # Chose the same as "name"
  version = '0.0.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'NLP Preprocessing library',   # Give a short description about your library
  author = 'Karthick Nagaraj',                   # Type in your name
  author_email = 'karthick12nagaraj@gmail.com',      # Type in your E-Mail
  url = ' ',   # Provide either the link to your github or to your website
  download_url = ' ',    # I explain this later on
  keywords = ['NLP','Preprocessing','spacy','NLTK','Transformers','Bert'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'numpy','pandas','textblob','nltk','textblob','unidecode','num2words','re','string','sklearn','gensim','tqdm','multiprocessing','matplotlib','seaborn','warnings','torch','transformers'],
         
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)

==> ML360_NLP_Preprocessing-0.0.2.tar.gz: ML360_NLP_Preprocessing-0.0.2/setup.py <==
from distutils.core import setup
setup(
  name = 'ML360_NLP_Preprocessing',         # How you named your package folder (MyLib)
  packages = ['ML360_NLP_Preprocessing'],   # Chose the same as "name"
  version = '0.0.2',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'NLP Preprocessing library',   # Give a short description about your library
  author = 'Karthick Nagaraj',                   # Type in your name
  author_email = 'karthick12nagaraj@gmail.com',      # Type in your E-Mail
  url = ' ',   # Provide either the link to your github or to your website
  download_url = ' ',    # I explain this later on
  keywords = ['NLP','Preprocessing','spacy','NLTK','Transformers','Bert'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'numpy','pandas','textblob','nltk','textblob','unidecode','num2words','string','sklearn','gensim','tqdm','multiprocessing','matplotlib','seaborn','warnings','torch','transformers'],
         
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
